%global major 0
%define libname %mklibname lldb %major
%define devname %mklibname -d lldb

Name:		lldb
Version:	3.9.1
Release:	%mkrel 4
Summary:	Next generation high-performance debugger
Group:		Development/Tools

License:	NCSA
URL:		http://llvm.org
Source0:	http://releases.llvm.org/%{version}/lldb-%{version}.src.tar.xz
# Fedora Patches (to remove use of private llvm headers)
Patch101: 0001-Replace-uses-of-MIUtilParse-CRegexParser-with-llvm-R.patch
Patch102: 0001-Remove-MIUtilParse-no-longer-used.patch
BuildRequires:	cmake
BuildRequires:  llvm-devel >= %{version}-5
BuildRequires:  clang-devel >= %{version}-3
BuildRequires:	libedit-devel
BuildRequires:  swig
BuildRequires:  llvm-static >= %{version}-5
BuildRequires:  libffi-devel
BuildRequires:  zlib-devel
BuildRequires:  libxml2-devel

%description
LLDB is a next generation, high-performance debugger. It is built as a set
of reusable components which highly leverage existing libraries in the
larger LLVM Project, such as the Clang expression parser and LLVM
disassembler.

%package -n %libname
Summary:	Libary for LLDB
Group:		Development/Other

%description -n %libname
The package contains libary for the LLDB debugger.

%package -n %devname
Summary:	Development header files for LLDB
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
# (tv) fix broken deps:
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libclang

%description -n %devname
The package contains header files for the LLDB debugger.

%package -n python-lldb
Summary:	Python module for LLDB
BuildRequires:	python2-devel
Requires:	python-six

%description -n python-lldb
The package contains the LLDB Python module.

%prep
%setup -q -n %{name}-%{version}.src

%patch101 -p1 -b .multi1
%patch102 -p1 -b .multi2

%build
# FC compatibility:
ln -sf build _build

rm tools/lldb-mi/MIUtilParse.*

# Python version detection is broken

LDFLAGS="%{?__global_ldflags} -lpthread -ldl"

CFLAGS="%{optflags} -fno-strict-aliasing -Wno-error=format-security -fno-rtti"
CXXFLAGS="%{optflags} -fno-strict-aliasing -Wno-error=format-security -fno-rtti"

%cmake .. \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_CONFIG:FILEPATH=/usr/bin/llvm-config \
	\
	-DLLDB_PATH_TO_LLVM_BUILD=%{_prefix} \
	-DLLDB_PATH_TO_CLANG_BUILD=%{_prefix} \
	\
	-DLLDB_DISABLE_CURSES:BOOL=OFF \
	-DLLDB_DISABLE_LIBEDIT:BOOL=OFF \
	-DLLDB_DISABLE_PYTHON:BOOL=OFF \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64 \
%else
	-DLLVM_LIBDIR_SUFFIX= \
%endif
	\
	-DPYTHON_EXECUTABLE:STRING=%{__python} \
	-DPYTHON_VERSION_MAJOR:STRING=$(%{__python} -c "import sys; print sys.version_info.major") \
	-DPYTHON_VERSION_MINOR:STRING=$(%{__python} -c "import sys; print sys.version_info.minor")

%make_build

%install
%make_install -C _build

# remove static libraries
rm -fv %{buildroot}%{_libdir}/*.a

# python: fix binary libraries location
liblldb=$(basename $(readlink -e %{buildroot}%{_libdir}/liblldb.so))
ln -vsf "../../../${liblldb}" %{buildroot}%{python_sitearch}/lldb/_lldb.so
mv -v %{buildroot}%{python_sitearch}/readline.so %{buildroot}%{python_sitearch}/lldb/readline.so

# remove bundled six.py
rm -f %{buildroot}%{python_sitearch}/six.*


%files
%{_bindir}/lldb*

%files -n %libname
%{_libdir}/liblldb.so.*

%files -n %devname
%{_includedir}/lldb
%{_libdir}/*.so

%files -n python-lldb
%{python_sitearch}/lldb


%changelog
* Wed Mar 29 2017 tmb <tmb> 3.9.1-4.mga6
+ Revision: 1095141
- rebuild for armv7hl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-3.mga6
+ Revision: 1095108
- rebuild for arm5tl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-2.mga6
+ Revision: 1095060
- rebuild with new llvm and clang

* Sat Jan 07 2017 ghibo <ghibo> 3.9.1-1.mga6
+ Revision: 1080456
- Update to release 3.9.1.
- Removed Patch0 (D15067) merged upstream
- Sync Patches (MIUtilParse) with Fedora.

* Tue Jul 12 2016 tmb <tmb> 3.8.1-1.mga6
+ Revision: 1041264
- update to 3.8.1 (maintenance release)

* Thu May 19 2016 akien <akien> 3.8.0-4.mga6
+ Revision: 1016999
- devel pkg: provide lldb-devel
- Use upstream RPM macros

* Mon May 02 2016 tv <tv> 3.8.0-3.mga6
+ Revision: 1008695
- fix devel broken deps
- fix requires on python-six

* Mon Mar 14 2016 tv <tv> 3.8.0-2.mga6
+ Revision: 990524
- use proper BR now that clang eventually got build
- submit to core/release

* Sat Mar 12 2016 tv <tv> 3.8.0-1.mga6
+ Revision: 989646
- fix llvm-config path
- fix build if %%__global_ldflags is not set
- temp BR fix as BS fails to upload build packages after hours
- new release
- imported package lldb


* Tue Mar 08 2016 Thierry Vignaud <tv@mageia.org> 3.8.0-1.mga6
- import from FC
